/*
 *
 * UAVCAN serialization support routines.                                                                     +-+ +-+
 *  Copyright (C) 2014 Pavel Kirienko <pavel.kirienko@gmail.com>                                              | | | |
 *  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.                                   \  -  /
 *  This software is distributed under the terms of the MIT License.                                            ---
 *                                                                                                               o
 * +------------------------------------------------------------------------------------------------------------------+
 */
#ifndef NUNAVUT_SUPPORT_HPP_INCLUDED
#define NUNAVUT_SUPPORT_HPP_INCLUDED

namespace nunavut
{
namespace support
{
// Target Endianess: {{ options.target_endianness }}
// TODO: create C++ support header

}  // namespace support
}  // namespace nunavut

#endif  // NUNAVUT_SUPPORT_HPP_INCLUDED
